===================================
Flounder Zipline-Sharadar Interface
===================================

.. image:: https://img.shields.io/travis/flounderteam/fsharadar.svg
        :target: https://travis-ci.org/flounderteam/fsharadar

.. image:: https://img.shields.io/pypi/v/fsharadar.svg
        :target: https://pypi.python.org/pypi/fsharadar


Flounder Zipline-Sharadar Interface

The Flounder Zipline-Sharadar interface represents the Flounder extension
of the `Zipline <https://github.com/quantopian/zipline>`_ quantitative research platform for ingesting and loading
`Sharadar <https://www.quandl.com/publishers/SHARADAR>`_ data.

The current version provides consolidated access to daily prices,
fundamentals, and metadata of US stocks for selecting
tradable universes and running multiple factors within the Zipline pipeline.

* Documentation: https://flounderteam.github.io/fsharadar/
* Installation: pip install cython fsharadar

